@@ -1,4 +1,5 @@
 import itertools
+import types
 import warnings
 
 import sheraf.exceptions
@@ -100,6 +101,14 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
 
     def __init__(self, *args, **kwargs):
         self._identifier = None
+
+        if not self.primary_key():
+            raise sheraf.exceptions.PrimaryKeyException(
+                "{} inherit from IndexedModel but has no primary key. Cannot create.".format(
+                    self.__class__.__name__
+                )
+            )
+
         super().__init__(*args, **kwargs)
 
     @classmethod
@@ -131,17 +140,6 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         """
         return sheraf.queryset.QuerySet(model_class=cls)
 
-    @classmethod
-    def create(cls, **kwargs):
-        if not cls.primary_key():
-            raise sheraf.exceptions.PrimaryKeyException(
-                "{} inherit from IndexedModel but has no primary key. Cannot create.".format(
-                    cls.__name__
-                )
-            )
-
-        return super().create(**kwargs)
-
     def initialize(self, **kwargs):
         if self.primary_key() in kwargs:
             identifier = kwargs[self.primary_key()]
@@ -439,11 +437,33 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         )
 
     def __setattr__(self, name, value):
+        yield_callbacks = []
         attribute = self.attributes.get(name)
+
         if attribute:
             was_created = attribute.is_created(self)
-            if was_created:
+            if not was_created:
+                prev_value = None
+                for callback in attribute.cb_creation:
+                    res = callback(self, value)
+                    if isinstance(res, types.GeneratorType):
+                        try:
+                            next(res)
+                        except StopIteration:
+                            pass
+                        yield_callbacks.append(res)
+
+            else:
                 prev_value = getattr(self, name)
+                for callback in attribute.cb_edition:
+                    res = callback(self, value, prev_value)
+                    if isinstance(res, types.GeneratorType):
+                        try:
+                            next(res)
+                        except StopIteration:
+                            pass
+                        yield_callbacks.append(res)
+
             old_values = self.before_index_edition(attribute)
 
         super().__setattr__(name, value)
@@ -458,15 +478,35 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
                     super().__setattr__(name, prev_value)
                 raise
 
+            for callback in yield_callbacks:
+                try:
+                    next(callback)
+                except StopIteration:
+                    pass
+
     def __delattr__(self, name):
+        yield_callbacks = []
         attribute = self.attributes.get(name)
         if attribute:
             old_values = self.before_index_edition(attribute)
+            for callback in attribute.cb_deletion:
+                res = callback(self, getattr(self, name))
+                if isinstance(res, types.GeneratorType):
+                    try:
+                        next(res)
+                    except StopIteration:
+                        pass
+                    yield_callbacks.append(res)
 
         super().__delattr__(name)
 
         if attribute:
             self.after_index_edition(attribute, old_values)
+            for callback in yield_callbacks:
+                try:
+                    next(callback)
+                except StopIteration:
+                    pass
 
     def before_index_edition(self, attribute):
         old_index_values = {}
@@ -645,16 +685,15 @@ class IndexedModel(BaseIndexedModel, metaclass=IndexedModelMetaclass):
     def index_manager(cls, index=None):
         return MultipleDatabaseIndexManager(cls.database_name, cls.table, index)
 
-    @classmethod
-    def create(cls, *args, **kwargs):
-        if "id" not in cls.attributes:
+    def __init__(self, *args, **kwargs):
+        if "id" not in self.__class__.attributes:
             raise sheraf.exceptions.PrimaryKeyException(
                 "{} inherit from IndexedModel but has no id attribute. Cannot create.".format(
-                    cls.__name__
+                    self.__class__.__name__
                 )
             )
 
-        return super().create(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class SimpleIndexedModel(BaseIndexedModel, metaclass=BaseIndexedModelMetaclass):
